==> qtjambi-serialbus-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiSerialBus/QModbusServer_shell.h <==
#ifndef QMODBUSSERVER_SHELL_H
#define QMODBUSSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSerialBus/qmodbusserver.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSerialBus/qmodbusdataunit.h>
#include <QtSerialBus/qmodbusdevice.h>
#include <QtSerialBus/qmodbuspdu.h>
#include <QtJambi/RegistryAPI>


class QModbusServer_shell : public QModbusServer, public QtJambiShellInterface
{
public:
    QModbusServer_shell(QObject* parent0 = nullptr);
    ~QModbusServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool open() override;
    QModbusResponse processPrivateRequest(const QModbusPdu& request0) override;
    QModbusResponse processRequest(const QModbusPdu& request0) override;
    bool processesBroadcast() const override;
    bool readData(QModbusDataUnit* newData0) const override;
    bool setMap(const QMap<QModbusDataUnit::RegisterType, QModbusDataUnit>& map0) override;
    bool setValue(int option0, const QVariant& value1) override;
    void timerEvent(QTimerEvent* event0) override;
    QVariant value(int option0) const override;
    bool writeData(const QModbusDataUnit& unit0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QModbusServer_access : public QModbusServer
{
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_open(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_processPrivateRequest_cref_QModbusPdu(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jobject __qt_processRequest_cref_QModbusPdu(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jboolean __qt_processesBroadcast_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_readData_QModbusDataUnit_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newData0) const;
    jboolean __qt_setMap_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject map0);
    jboolean __qt_setValue_int_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint option0, jobject value1);
    jobject __qt_value_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint option0) const;
    jboolean __qt_writeData_cref_QModbusDataUnit(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID unit0);
};

#endif // QMODBUSSERVER_SHELL_H

==> qtjambi-serialbus-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiSerialBus/QModbusServer_shell.h <==
#ifndef QMODBUSSERVER_SHELL_H
#define QMODBUSSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtSerialBus/qmodbusserver.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSerialBus/qmodbusdataunit.h>
#include <QtSerialBus/qmodbusdevice.h>
#include <QtSerialBus/qmodbuspdu.h>
#include <QtJambi/RegistryAPI>


class QModbusServer_shell : public QModbusServer, public QtJambiShellInterface
{
public:
    QModbusServer_shell(QObject* parent0 = nullptr);
    ~QModbusServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool open() override;
    QModbusResponse processPrivateRequest(const QModbusPdu& request0) override;
    QModbusResponse processRequest(const QModbusPdu& request0) override;
    bool processesBroadcast() const override;
    bool readData(QModbusDataUnit* newData0) const override;
    bool setMap(const QMap<QModbusDataUnit::RegisterType, QModbusDataUnit>& map0) override;
    bool setValue(int option0, const QVariant& value1) override;
    void timerEvent(QTimerEvent* event0) override;
    QVariant value(int option0) const override;
    bool writeData(const QModbusDataUnit& unit0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QModbusServer_access : public QModbusServer
{
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_open(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_processPrivateRequest_cref_QModbusPdu(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jobject __qt_processRequest_cref_QModbusPdu(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jboolean __qt_processesBroadcast(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_readData_QModbusDataUnit_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID newData0) const;
    jboolean __qt_setMap_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject map0);
    jboolean __qt_setValue_int_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint option0, jobject value1);
    jobject __qt_value_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint option0) const;
    jboolean __qt_writeData_cref_QModbusDataUnit(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID unit0);
};

#endif // QMODBUSSERVER_SHELL_H
